summaryrefslogtreecommitdiff
path: root/software
diff options
context:
space:
mode:
Diffstat (limited to 'software')
-rw-r--r--software/ihu/ihu.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/software/ihu/ihu.asm b/software/ihu/ihu.asm
index e7c1e5e..a4c53a4 100644
--- a/software/ihu/ihu.asm
+++ b/software/ihu/ihu.asm
@@ -180,8 +180,8 @@ init
;; bank 3
bsf STATUS,RP0
bsf STATUS,RP1
- ;; movlw b'00001000' ; TX non-inverted, 8bit Baudrate, no auto baud detect
- movlw b'00011000' ; TX inverted, 8bit Baudrate, no auto baud detect
+ ;; movlw b'00001000' ; TX non-inverted, 16bit Baudrate, no auto baud detect
+ movlw b'00011000' ; TX inverted, 16bit Baudrate, no auto baud detect
movwf BAUDCTL
movlw b'11101111' ; AN0-AN3,AN5-AN7 as analog
movwf ANSEL ; AN4 as digital